﻿using System;
using System.Collections.ObjectModel;
using Windows.Foundation;
using Windows.Graphics.Display;
using Windows.UI.ViewManagement;
using Windows.UI.Xaml;
using Windows.UI.Xaml.Controls;

namespace TestProject
{
    /// <summary>
    /// 메인 페이지
    /// </summary>
    public sealed partial class MainPage : Page
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Property
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 카테고리 베이스 컬렉션 - CategoryBaseCollection

        /// <summary>
        /// 카테고리 베이스 컬렉션
        /// </summary>
        public ObservableCollection<CategoryBase> CategoryBaseCollection { get; set; }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 생성자 - MainPage()

        /// <summary>
        /// 생성자
        /// </summary>
        public MainPage()
        {
            InitializeComponent();

            #region 윈도우 크기를 설정한다.

            double width  = 800d;
            double height = 600d;

            double dpi = (double)DisplayInformation.GetForCurrentView().LogicalDpi;

            ApplicationView.PreferredLaunchWindowingMode = ApplicationViewWindowingMode.PreferredLaunchViewSize;

            Size windowSize = new Size(width * 96d / dpi, height * 96d / dpi);

            ApplicationView.PreferredLaunchViewSize = windowSize;

            Window.Current.Activate();

            ApplicationView.GetForCurrentView().TryResizeView(windowSize);

            #endregion
            #region 윈도우 제목을 설정한다.

            ApplicationView.GetForCurrentView().Title = "NavigationView 엘리먼트 : MenuItemsSource 속성을 사용해 데이터 바인딩하기";

            #endregion

            CategoryBaseCollection = new ObservableCollection<CategoryBase>();

            CategoryBaseCollection.Add(new Category { Name = "카테고리 1", Glyph = Symbol.Home    , Tooltip = "카테고리 1 입니다.", Tag = "SamplePage1" });
            CategoryBaseCollection.Add(new Category { Name = "카테고리 2", Glyph = Symbol.Keyboard, Tooltip = "카테고리 2 입니다.", Tag = "SamplePage2" });
            CategoryBaseCollection.Add(new Category { Name = "카테고리 3", Glyph = Symbol.Library , Tooltip = "카테고리 3 입니다.", Tag = "SamplePage3" });
            CategoryBaseCollection.Add(new Category { Name = "카테고리 4", Glyph = Symbol.Mail    , Tooltip = "카테고리 4 입니다.", Tag = "SamplePage4" });

            this.navigationView.SelectedItem = CategoryBaseCollection[0];
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region 네비게이션 뷰 선택 변경시 처리하기 - navigationView_SelectionChanged(sender, e)

        /// <summary>
        /// 네비게이션 뷰 선택 변경시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void navigationView_SelectionChanged(Microsoft.UI.Xaml.Controls.NavigationView sender, Microsoft.UI.Xaml.Controls.NavigationViewSelectionChangedEventArgs e)
        {
            if(e.IsSettingsSelected)
            {
                this.frame.Navigate(typeof(SampleSettingPage));
            }
            else
            {
                Category catetory = e.SelectedItem as Category;

                string tag = catetory.Tag.ToString();

                sender.Header = catetory.Name;

                string typeName = "TestProject." + tag;

                Type pageType = Type.GetType(typeName);

                this.frame.Navigate(pageType);
            }
        }

        #endregion
    }
}