﻿using Windows.UI.Xaml;
using Windows.UI.Xaml.Controls;
using Windows.UI.Xaml.Markup;

namespace TestProject
{
    /// <summary>
    /// 메뉴 항목 템플리트 셀렉터
    /// </summary>
    [ContentProperty(Name = "ItemTemplate")]
    public class MenuItemTemplateSelector : DataTemplateSelector
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Field
        ////////////////////////////////////////////////////////////////////////////////////////// Internal

        #region Field

        /// <summary>
        /// 헤더 템플리트
        /// </summary>
        internal DataTemplate HeaderTemplate = (DataTemplate)XamlReader.Load
        (
            @"<DataTemplate xmlns='http://schemas.microsoft.com/winfx/2006/xaml/presentation'><NavigationViewItemHeader Content='{Binding Name}' /></DataTemplate>"
        );

        /// <summary>
        /// 분리자 템플리트
        /// </summary>
        internal DataTemplate SeparatorTemplate = (DataTemplate)XamlReader.Load
        (
            @"<DataTemplate xmlns='http://schemas.microsoft.com/winfx/2006/xaml/presentation'><NavigationViewItemSeparator /></DataTemplate>"
        );

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Property
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 항목 템플리트 - ItemTemplate

        /// <summary>
        /// 항목 템플리트
        /// </summary>
        public DataTemplate ItemTemplate { get; set; }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Protected

        #region 템플리트 선택하기 (코어) - SelectTemplateCore(item)

        /// <summary>
        /// 템플리트 선택하기 (코어)
        /// </summary>
        /// <param name="item">항목</param>
        /// <returns>템플리트</returns>
        protected override DataTemplate SelectTemplateCore(object item)
        {
            return item is Separator ? SeparatorTemplate : item is Header ? HeaderTemplate : ItemTemplate;
        }

        #endregion
        #region 템플리트 선택하기 (코어) - SelectTemplateCore(item, container)

        /// <summary>
        /// 템플리트 선택하기 (코어)
        /// </summary>
        /// <param name="item">항목</param>
        /// <param name="container">컨테이너</param>
        /// <returns>템플리트</returns>
        protected override DataTemplate SelectTemplateCore(object item, DependencyObject container)
        {
            return item is Separator ? SeparatorTemplate : item is Header ? HeaderTemplate : ItemTemplate;
        }

        #endregion
    }
}